/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.cocoon.pipeline.util;

import java.io.BufferedInputStream;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.Properties;

import javax.xml.transform.TransformerFactory;
import javax.xml.transform.sax.SAXTransformerFactory;
import javax.xml.transform.sax.TransformerHandler;
import javax.xml.transform.stream.StreamResult;

import org.apache.cocoon.pipeline.component.sax.XMLConsumer;
import org.xml.sax.InputSource;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.XMLReaderFactory;

public abstract class XMLUtils {

    private static final SAXTransformerFactory SAX_TRANSFORMER_FACTORY = (SAXTransformerFactory) TransformerFactory
            .newInstance();

    public static void toSax(InputStream inputStream, XMLConsumer xmlConsumer) {
        try {
            XMLReader xmlReader = XMLReaderFactory.createXMLReader();
            xmlReader.setContentHandler(xmlConsumer);
            xmlReader.setProperty("http://xml.org/sax/properties/lexical-handler", xmlConsumer);

            inputStream = new BufferedInputStream(inputStream);
            xmlReader.parse(new InputSource(inputStream));
        } catch (Exception e) {
            throw new RuntimeException("Can't parse inputStream.", e);
        }
    }

    public static void toOutputStream(OutputStream outputStream, SaxBuffer saxBuffer) {
        try {
            TransformerHandler transformerHandler = SAX_TRANSFORMER_FACTORY.newTransformerHandler();
            Properties properties = new Properties();
            properties.put("method", "xml");
            transformerHandler.getTransformer().setOutputProperties(properties);
            transformerHandler.setResult(new StreamResult(outputStream));

            transformerHandler.startDocument();
            saxBuffer.toSAX(new EmbeddedXMLPipe(transformerHandler));
            transformerHandler.endDocument();
        } catch (Exception e) {
            throw new RuntimeException("Can't stream the provided SaxBuffer.", e);
        }
    }

}