/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.cocoon.servlet.node;

import org.apache.cocoon.pipeline.Pipeline;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;

@Aspect
public class LastModifiedCollector {

    private static final ThreadLocal<Long> THREAD_LOCAL = new ThreadLocal<Long>();

    public static long getLastModified() {
        return THREAD_LOCAL.get();
    }

    public static void clearLastModified() {
        THREAD_LOCAL.set(null);
    }

    @Around("execution(* org.apache.cocoon.pipeline.Pipeline.execute(..))")
    public Object interceptInvoke(ProceedingJoinPoint proceedingJoinPoint) throws Throwable {
        Object result = proceedingJoinPoint.proceed();

        Pipeline pipeline = (Pipeline) proceedingJoinPoint.getTarget();
        long lastModified = pipeline.getLastModified();
        THREAD_LOCAL.set(lastModified);

        return result;
    }
}
